Enum Event
#[non_exhaustive]pub enum Event<'a> {
Enter,
Leave,
Position {
x: i32,
y: i32,
},
Hotspot {
x: i32,
y: i32,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Enter
cursor entered captured area
Sent when a cursor enters the captured area. It shall be generated before the “position” and “hotspot” events when and only when a cursor enters the area.
The cursor enters the captured area when the cursor image intersects with the captured area. Note, this is different from e.g. wl_pointer.enter.
Leave
cursor left captured area
Sent when a cursor leaves the captured area. No “position” or “hotspot” event is generated for the cursor until the cursor enters the captured area again.
Position
position changed
Cursors outside the image capture source do not get captured and no event will be generated for them.
The given position is the position of the cursor’s hotspot and it is relative to the main buffer’s top left corner in transformed buffer pixel coordinates. The coordinates may be negative or greater than the main buffer size.
Hotspot
hotspot changed
The hotspot describes the offset between the cursor image and the position of the input device.
The given coordinates are the hotspot’s offset from the origin in buffer coordinates.
Clients should not apply the hotspot immediately: the hotspot becomes effective when the next ext_image_copy_capture_frame_v1.ready event is received.
Compositors may delay this event until the client captures a new frame.
Implementations