Struct ExtImageCopyCaptureCursorSessionV1

pub struct ExtImageCopyCaptureCursorSessionV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
cursor capture session

This object represents a cursor capture session. It extends the base capture session with cursor-specific metadata.

See also the Request enum for this interface.

Implementations



impl ExtImageCopyCaptureCursorSessionV1

pub fn enter(&self)

cursor entered captured area

Sent when a cursor enters the captured area. It shall be generated before the “position” and “hotspot” events when and only when a cursor enters the area.

The cursor enters the captured area when the cursor image intersects with the captured area. Note, this is different from e.g. wl_pointer.enter.

pub fn leave(&self)

cursor left captured area

Sent when a cursor leaves the captured area. No “position” or “hotspot” event is generated for the cursor until the cursor enters the captured area again.

pub fn position(&self, x: i32, y: i32)

position changed

Cursors outside the image capture source do not get captured and no event will be generated for them.

The given position is the position of the cursor’s hotspot and it is relative to the main buffer’s top left corner in transformed buffer pixel coordinates. The coordinates may be negative or greater than the main buffer size.

pub fn hotspot(&self, x: i32, y: i32)

hotspot changed

The hotspot describes the offset between the cursor image and the position of the input device.

The given coordinates are the hotspot’s offset from the origin in buffer coordinates.

Clients should not apply the hotspot immediately: the hotspot becomes effective when the next ext_image_copy_capture_frame_v1.ready event is received.

Compositors may delay this event until the client captures a new frame.